package String::Comments::Extract::CPP;

use strict;
use warnings;

use base qw/String::Comments::Extract::SlashStar/;

1;
